@@ -9,7 +9,7 @@ from .funcmakers import wrap_mapper, wrap_selector
 __all__ = [
     'count', 'cycle', 'repeat', 'repeatedly', 'iterate',
     'take', 'drop', 'first', 'second', 'rest', 'ilen',
-    'map', 'filter', 'imap', 'ifilter', 'remove', 'iremove', 'keep', 'ikeep',
+    'map', 'filter', 'imap', 'ifilter', 'remove', 'iremove', 'keep', 'ikeep', 'without', 'iwithout',
     'concat', 'iconcat', 'chain', 'cat', 'icat', 'mapcat', 'imapcat',
     'izip', 'interleave', 'interpose', 'distinct',
     'dropwhile', 'takewhile', 'split', 'split_at', 'split_by',
@@ -76,6 +76,15 @@ def ikeep(f, seq=EMPTY):
     else:
         return ifilter(bool, imap(f, seq))
 
+def iwithout(seq, *items):
+    for value in seq:
+        if not value in items:
+            yield value
+
+def without(seq, *items):
+    return list(iwithout(seq, *items))
+
+
 def concat(*seqs):
     return list(chain(*seqs))
 iconcat = chain
